### A Pluto.jl notebook ###
# v0.19.22

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
end

# ╔═╡ a145e2fe-a903-11eb-160f-df7ea83fa3e6
begin
	using PlotlyBase, HypertextLiteral, PlutoUI
	using CSV, DataFrames, Dates, PeriodicalDates
	using SparseArrays, StatsBase
	#import PlotlyJS:savefig
end

# ╔═╡ 943edb36-acc8-4b2a-94ab-c544f9eb279b
md"""
# Week 7 - Aggregate Supply & the Phillips Curve

## Exercises

**Macroeconomics, ISCTE-IUL**
"""

# ╔═╡ 1245aef9-18ce-42f5-af82-c2e6cce70798
md"""
**Vivaldo Mendes, Ricardo Gouveia-Mendes, Luís Clemente-Casinhas; March 2023**
"""

# ╔═╡ 4618a663-f77e-4ccc-9b00-e84dbd5beb34
md"""
### Packages
"""

# ╔═╡ 74de9f66-d5b4-4e0f-a75d-5177b1842191
begin
	function Base.show(io::IO, mimetype::MIME"text/html", plt::PlotlyBase.Plot)
       # Remove responsive flag on the plot as we handle responsibity via ResizeObeserver and leaving it on makes the div flickr during updates
	hasproperty(plt,:config) && plt.config.responsive && (plt.config.responsive = false)   
	show(io,mimetype, @htl("""
			<div>
			<script id=asdf>
			const {plotly} = await import("https://cdn.plot.ly/plotly-2.2.0.min.js")
			const PLOT = this ?? document.createElement("div");
		

		
			Plotly.react(PLOT, $(HypertextLiteral.JavaScript(PlotlyBase.json(plt))));


		
			const pluto_output = currentScript.parentElement.closest('pluto-output')

			const resizeObserver = new ResizeObserver(entries => {
				Plotly.Plots.resize(PLOT)
			})

			resizeObserver.observe(pluto_output)

			invalidation.then(() => {
				resizeObserver.disconnect()
			})
		
			return PLOT
			</script>
			</div>
	"""))
	end
end

# ╔═╡ add07024-b7eb-445d-b4f4-6a6757c2ecd3
md"""
## Exercise 1. Inflation versus unemployment
"""

# ╔═╡ bfb890be-fba4-4d55-9e39-a52d40a5adad
md"""

We will use the data in the file "ASdata.csv" for most of this week's exercises. That file includes monthly observations, covering the US economy over the period 1960-2022, of the following macroeconomic aggregates: the rate of inflation (CPI), the unemployment rate (UR), international oil prices (Oil), and the growth rate of oil prices (Oil_growth).

This exercise will focus on the Phillips curve's relationship between inflation and unemployment.

(a) In Fig 1, we plot the time series of those two variables, and the cross-plot is presented in Fig 2. Can you spot any relationship between those two variables that may resemble the "Phillips Curve"?

(b) Fig 3 presents the relationship for the 1960s. Do you see an apparent Phillips curve over there?

(c) In Figs 4 and 5, we get the relationship for the 1970s and the 1980s. What conclusions can we put forward?

(d) Finally, in Figs 6 and 7, we get the relationship for the 2000s and 2010s. What conclusions can we put forward?

"""

# ╔═╡ ec4b312d-c945-4d24-ad88-6fa15ed6f0f1
md"""
---
"""

# ╔═╡ 518caed6-cb92-4410-bc0a-7a5c7bdc155e
ASdata = CSV.read("ASdata.csv", DataFrame);

# ╔═╡ f613e456-403b-4bff-bd65-315b1be5eb45
period1_1 = MonthlyDate(1960, 1):Month(1):MonthlyDate(2022, 9);

# ╔═╡ 6c66bff7-47ef-4926-8d56-2c92d6eb485b
begin
	trace1_1 = scatter(;x = Date.(period1_1), y = ASdata[:,3], name = "UR", line_color = "Blue", 
						mode = "lines", line_width="1.5", marker_size ="0")
	
	trace1_2 = scatter(;x = Date.(period1_1), y = ASdata[:,2], name = "CPI", line_color = "Red", 
						mode = "lines", line_width="1.5", marker_size ="0")

	layout1_2 = Layout(;
		
				title_text = "Fig 01. Inflation Rate (CPI) versus Unemployment Rate (UR): USA (1960--2022)",
				title_x = 0.5,
				hovermode="x",
		
            	xaxis = attr(
                	title = "Monthly obervations"
                	#tickformat = "%Y",
                	#hoverformat = "%Y-Q%q",
                	#tick0 = "1960/01/01",
               	 	#dtick = "M120"
				),
		
        		#xaxis_range = [1960, 2020],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)

	p1_2 = Plot([trace1_1 , trace1_2], layout1_2)
end

# ╔═╡ fdec5907-d925-4ae2-9298-fd14f3213139
begin
	
	layout1_3 = Layout(;
					title_text = "Fig 02. Inflation versus Unemployment: USA (1960--2022)",
					title_x = 0.5,
        			yaxis_title = "Rate of inflation",
        			#xaxis_range = [1960, 2020],
        			xaxis_title = "Rate of unemployment",
        			#yaxis_range=[-2, 2], 
        			titlefont_size=18)

	p1_3 = Plot(ASdata[:,3], ASdata[:,2], mode="markers+lines", text=period1_1,
            	marker_symbol="circle", marker_size="7",line_width=0.5, 
            	#marker_color="LightSteelBlue",
            	marker_color="BlueViolet",layout1_3)
	
end

# ╔═╡ 78475df7-5d81-410c-97bb-9ce06e897a7e
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ b31105dd-a43d-4640-a13c-e19f7e879ca2
period1_2 = MonthlyDate(1960, 1):Month(1):MonthlyDate(1969, 12);

# ╔═╡ 7bc32249-45ff-42bf-8d39-ec1a7670fbdd
begin
	
	layout1_4 = Layout(;
					title_text = "Fig 03. Inflation versus Unemployment: USA 1960s",
					title_x = 0.5,
        			yaxis_title = "Rate of inflation",
        			#xaxis_range = [1960, 2020],
        			xaxis_title = "Unemployment rate",
        			#yaxis_range=[-2, 2], 
        			titlefont_size=18)

	p1_4 = Plot(ASdata[1:120,3], ASdata[1:120,2], mode="markers+lines", text=period1_2,
            	marker_symbol="circle", marker_size="8",line_width=0.5, 
            	#marker_color="LightSteelBlue",
            	marker_color="Blue",layout1_4)
end

# ╔═╡ 04b850b4-e659-4f1c-82be-ba912bad03af
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ 066f8df6-7d9c-4137-b0a2-5f1c5eb3a1d7
period1_3 = MonthlyDate(1970, 1):Month(1):MonthlyDate(1979, 12);

# ╔═╡ 24f2f06e-05fe-4b12-b238-d660f449ee9b
begin
	
	layout1_5 = Layout(;
					title_text = "Fig 04. Inflation versus Unemployment: USA 1970s",
					title_x = 0.5,
        			yaxis_title = "Rate of inflation",
        			#xaxis_range = [1960, 2020],
        			xaxis_title = "Unemployment rate",
        			#yaxis_range=[-2, 2], 
        			titlefont_size=18)

	p1_5 = Plot(ASdata[121:240, 3], ASdata[121:240, 2], mode="markers+lines", text=period1_3,
            	marker_symbol="circle", marker_size="8",line_width=0.5, 
            	#marker_color="LightSteelBlue",
            	marker_color="Darkblue",layout1_5)
end

# ╔═╡ 4215ce6d-b49f-4dcb-a9de-5be9661d65f2
period1_4 = MonthlyDate(1980, 1):Month(1):MonthlyDate(1989, 12);

# ╔═╡ 793b3108-76c1-4274-9861-c9ee948eca88
begin
	layout1_6 = Layout(;
					title_text = "Fig 05. Inflation versus Unemployment: USA 1980s",
					title_x = 0.5,
        			yaxis_title = "Rate of inflation",
        			#xaxis_range = [1960, 2020],
        			xaxis_title = "Unemployment rate",
        			#yaxis_range=[-2, 2], 
        			titlefont_size=18)

	p1_6 = Plot(ASdata[241:360, 3], ASdata[241:360, 2], mode="markers+lines", text=period1_4,
            	marker_symbol="circle", marker_size="8",line_width=0.5, 
            	#marker_color="LightSteelBlue",
            	marker_color="Darkred",layout1_6)
end

# ╔═╡ 24f78b7c-7bda-4ea1-b593-bdacb94e8c4d
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ 86194b6d-e8e0-4790-ab47-d12f691beef2
period1_6 = MonthlyDate(2000, 1):Month(1):MonthlyDate(2009, 12);

# ╔═╡ aa86d58a-214d-4ef3-a2a3-86b78af55967
begin
	layout1_7 = Layout(;
					title_text = "Fig 06. Inflation versus Unemployment: USA 2000s",
					title_x = 0.5,
        			yaxis_title = "Rate of inflation",
        			#xaxis_range = [1960, 2020],
        			xaxis_title = "Unemployment rate",
        			#yaxis_range=[-2, 2], 
        			titlefont_size=18)

	p1_7 = Plot(ASdata[481:600, 3], ASdata[481:600, 2], mode="markers+lines", text=period1_6,
            	marker_symbol="circle", marker_size="8",line_width=0.5, 
            	#marker_color="LightSteelBlue",
            	marker_color="Purple",layout1_7)
end

# ╔═╡ a6a4a528-b4eb-4521-9cba-d8a02b0c3720
period1_7 = MonthlyDate(2010, 1):Month(1):MonthlyDate(2022, 9);

# ╔═╡ af88f312-87dd-4a1e-913d-31ba12f06b45
begin
	layout1_9 = Layout(;
					title_text = "Fig 07. Inflation versus Unemployment: USA 2010-2022",
					title_x = 0.5,
        			yaxis_title = "Rate of inflation",
        			#xaxis_range = [1960, 2020],
        			xaxis_title = "Unemployment rate",
        			#yaxis_range=[-2, 2], 
        			titlefont_size=18)

	p1_9 = Plot(ASdata[601:753, 3], ASdata[601:753, 2], mode="markers+lines", text=period1_7,
            	marker_symbol="circle", marker_size="8",line_width=0.5, 
            	#marker_color="LightSteelBlue",
            	marker_color="olive", layout1_9)
end

# ╔═╡ f4d5a7be-361c-4a52-b501-b363548e42ee
md"""
!!! answer "Answer (d)"

	It is not easy to understand what has happened during the 2000s and since 2010 to the Phillips Curve (PC). Probably, nobody knows for sure why we see such bizarre behaviors in this curve. These 22 years have been characterized by tremendous instability in oil prices, by the biggest financial crisis the world has seen since the 1920s (2008-2014), a large war in the Middle East, the Covid-19 pandemic of catastrophic proportions, and now a war in Europe of unknown repercussions.

	So, do not feel so uneasy with the Phillips curve. We just have too many shocks.

"""

# ╔═╡ dcd13560-0f73-4aaa-b59a-b7961d8cdc63
md"""
## Exercise 2. Inflationary expectations
"""

# ╔═╡ 7f67d656-bb55-4097-ba49-10140f9b3502
md"""

Consider the following equations, which describe the expectations-augmented Phillips Curve: 

$$\pi=\pi^{e}-\omega\left(U-U_{n}\right) \ , \quad \omega=1.2 \ , \quad \pi_{t}^{e}=\pi_{t-1}$$

Assuming that, in this economy, the natural unemployment rate $U_n=4\%$, current unemployment is $U=4\%$, current inflation is $\pi=2\%$, and expected-inflation is $\pi^e = 2\%$:

(a) What happens to inflation over the next nine years if the central bank tries to bring the unemployment rate down to 3%, starting next year?

(b) What do we call this type of inflation dynamics?

(c) The monetary authorities have a target value for inflation: $\pi^T =2 \%$. Is this target value compatible with 3% unemployment? What is the option available to the monetary authorities for achieving that target? 

"""

# ╔═╡ beb52783-708e-4782-b271-643f2a4f3297
md"""
!!! answer "Answer (a)"

	Here
"""

# ╔═╡ 66463532-449b-4cac-8083-8938786a193b
begin
	t = 10 # number of iterations we want to simulate
	ω = 1.2 # parameter
	Un = 4.0 # Natural rate of unemployment
	Uc = 3.0 # Unemployment rate chosen by the monetary authorities
	π1 = 2.0 # the initial condition we stipulate
	p = length(π1) # telling the routine how many initial conditions
	π = [π1  zeros(p,t-1)] # preallocation to increase performance

		 for i = 1 : t-1 # 9 iterations in the for loop
			 π[i+1] = π[i] - ω * (Uc - Un) 
		 end

	layout7_10 = Layout(;
					title_text = "The Phillips Curve: inflation created by inflationary expectations",
					title_x = 0.5,
        			yaxis_title = "Rate of inflation",
					hovermode="x",
        			#xaxis_range = [1,10],
        			xaxis_title = "Time",
        			#yaxis_range=[-2, 2], 
        			titlefont_size=18)
	Plot(1:t, π', mode="markers+lines", marker_symbol="circle", marker_size="9",line_width=0.5, 
            		marker_color="Blue", layout7_10)
end

# ╔═╡ 28e51405-60fb-496c-b3cd-5aa256243b8e
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ 57787a16-2568-4fcb-94cf-7f5533facf05
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ a91c2b80-3215-46ac-938c-ef98e4dde437
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 95dce14a-b5f9-4dd8-af46-415e71b425fb
md"""
## Exercise 3. Deflationary expectations
"""

# ╔═╡ 62d8a5a1-eab1-49ae-8947-b5299d1217c5
md"""

Assume the same information as in the previous exercise. 

(a) What happens to inflation over the next nine years if the central bank tries to increase the unemployment rate up to 5%, starting next year?

(b) What do we call this type of inflation dynamics?

(c) The monetary authorities have a target value for inflation: $\pi^T =2 \%$. Is this target value compatible with 5% unemployment? What is the option available to the monetary authorities for achieving that target? 

"""

# ╔═╡ 6949d31b-c934-42f8-a53e-8fd1e068fff4
md"""
!!! answer "Answer (a)"

	Here
"""

# ╔═╡ 95b7bd36-e0fc-4464-8bbe-9e9f491dae64
begin
	t_3 = 10 # number of iterations we want to simulate
	ω_3 = 1.2 # parameter
	Un_3 = 4.0 # Natural rate of unemployment
	Uc_3 = 5.0 # Unemployment rate chosen by the monetary authorities
	π1_3 = 2.0 # the initial condition we stipulate
	p_3 = length(π1_3) # telling the routine how many initial conditions are in the loop
	π_3 = [π1_3 zeros(p_3, t_3-1)] # preallocation to increase performance

		 for j = 1 : t_3-1 # the "for" loop
			 π_3[j+1] = π_3[j] - ω_3* (Uc_3 - Un_3) 
		 end

	layout7_11 = Layout(;
					title_text = "Deflation created by deflationary expectations",
					title_x = 0.5,
        			yaxis_title = "Rate of inflation",
					hovermode="x",
        			#xaxis_range = [1,10],
        			xaxis_title = "Time",
        			#yaxis_range=[-2, 2], 
        			titlefont_size=18)
	Plot(1:t, π_3', mode="markers+lines", marker_symbol="circle", marker_size="9",line_width=0.5, 
            		marker_color="Darkblue", layout7_11)
end

# ╔═╡ 21d79f5f-f03a-4d63-8f79-d8868bd9234d
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ 763bc186-dae2-479c-8195-6585b46733be
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ 6c8886d7-3dec-4d2f-8aa9-85ad714cee7f
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ f0196aef-6843-4f69-b387-ca5deec33604
md"""
## Exercise 4. The US labor market is too hot
"""

# ╔═╡ 10ccbe74-dff0-4f84-9b8d-3563559be3ba
md"""
>“The labor market is too hot for the Fed [the unemployment rate falling to 3.5%]. I think it keeps them on a pretty aggressive tightening path. I expect another 75 basis point hike in November. They can hopefully moderate and reduce the size of rate hike to 50 basis points in December,” Kathy Bostjancic, chief U.S. economist at Oxford Economics, 7 October 2022.

According to the concept of the Pillips Curve, what does it mean "the labor market is too hot for the Fed"?
"""

# ╔═╡ d333ae08-ecb5-454f-a963-2dc33583d21c
md"""
!!! answer

	Here

"""

# ╔═╡ adc62dc5-e66e-4eba-9eb5-4cea6dd0efa9
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ b210c2e6-c9a5-44d8-a01c-c9702da0606d
md"""
## Exercise 5. Is the US labor market too hot?
"""

# ╔═╡ aea3a28e-c408-4a6d-ac6a-1507ed4e4d1b
md"""
>"Most seers believe the US labor market is overly strong. Federal Reserve Chair Jerome Powell recently described it as “extremely tight” and “out of balance,” with demand for workers far outstripping supply.  I beg to differ." Gary Shilling, Bloomberg, 4 October 2022


As usual, in macroeconomics, there is a massive controversy about the current situation of the US labor market. If the US labor market were "so hot", how can it be that real wages have been declining since 2021? Or how can the participation rate still be below the pre-pandemic level? We do not have much space here, but just a hint in the following figure: in February 2020 (before the pandemic started), unemployment as 3.5% and inflation was 2.46%; in September 2022, unemployment was 3.5% (!!), while inflation reached 8.22%. How is this compatible with a too-hot labor market? Gary Shilling does not see how the two facts can be conjugated to deliver such a message: 

"""

# ╔═╡ c1a3d11b-881c-4c74-ac1d-e794562349e0
md"""
>"My analysis indicates that current labor market stringency isn’t due to robust demand for workers but because Americans are limiting the supply after the pandemic. After staying at home for two years due to the lockdowns, many people became accustomed to working remotely and putting in fewer hours while others dropped out, retiring early. In late September, office occupancy as measured by workers at actual desks was only 47.5% of early 2020, according to Kastle Systems."  [here](https://www.bloomberg.com/opinion/articles/2022-10-04/the-us-labor-market-is-looser-than-it-appears)
"""

# ╔═╡ 778b7504-2f80-480e-bf43-cdbea4be4514
begin
	trace10_1 = scatter(;x = Date.(period1_7), y = ASdata[601:end,3], name = "UR", line_color = "Blue", 
						mode = "lines", line_width="2", marker_size ="0")
	
	trace10_2 = scatter(;x = Date.(period1_7), y = ASdata[601:end,2], name = "CPI", line_color = "Red", 
						mode = "lines", line_width="2", marker_size ="0")

	layout10_2 = Layout(;
		
				title_text = "Inflation Rate (CPI) versus Unemployment Rate (UR): USA (2010--2022)",
				title_x = 0.5,
				hovermode="x",
		
            	xaxis = attr(
                	title = "Monthly obervations"
                	#tickformat = "%Y",
                	#hoverformat = "%Y-Q%q",
                	#tick0 = "1960/01/01",
               	 	#dtick = "M120"
				),
		
        		#xaxis_range = [1960, 2020],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)

	p0_2 = Plot([trace10_1 , trace10_2], layout10_2)
end

# ╔═╡ 854c4538-8d47-41f6-ba61-edfd81f632d1
md"""
!!! answer "Suggested answer"

	Here

"""

# ╔═╡ 2d9beabe-d549-4bc3-9598-adb01169ffa0
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 3cf86819-09f0-43d3-aff7-494be276bf0f
md"""
## Exercise 6. Cyclical unemployment & the output-gap
"""

# ╔═╡ ccc8aa66-cb8d-4bbe-8457-f496f7bff47d
md"""

Using the file "US_Data_May2021.csv", in this exercise we will deal with the Okuns' law for the USA, during the period between 1960.Q1 and 2019.Q4. 

(a) In Fig 6.1 and 6.2 we plot the evolution of the unemployment rate, its trend, and cyclical rate of unemployment.
What is cyclical unemployment? How can we obtain it?

"""

# ╔═╡ dc5bfa8c-7247-44fc-8837-a7fa32c36d54
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ d040f3bb-7ea9-4000-813a-6e1f4e0163cb
md"""

(b) In Figures 6.3 and 6.4, we plot the evolution of the real GDP, its trend, and the output gap. What is the output gap? How can we obtain it? 

"""

# ╔═╡ ea2e3d0e-c933-4d67-ac24-3ba9bcf6fc8a
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ 2ab10860-0671-4e3c-a7ea-dff6ae80c528
md"""

(c) Fig 6.5 displays Okun's law for the US. For the period under consideration (1960.Q1-2019.Q4), the Okuns's law has an intercept equal to $0$ and a slope equal to $-0.441393$ (see figure below). What is this law? How do we obtain it?

"""

# ╔═╡ cc770177-1d7a-4f6e-a930-c805b3bfee6d
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ 707413b6-3726-430c-a3b4-8cc768b448dc
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 86f54c54-58a5-4faf-9688-baddaa032ed2
md"""
## Exercise 7. The Okun's law
"""

# ╔═╡ c0bb7086-533d-4c95-850a-b445b877d8c8
md"""

*From the textbook.*


Suppose the Okun’s law can be expressed according to the following formula:

$$U - U_n = -0.5(Y - Y^P).$$ 

Assuming that potential output grows at a steady rate of 2.5% and that the natural rate of unemployment
remains unchanged:

(a) Calculate by how much unemployment increases when real GDP decreases by one percentage point.

(b) Calculate by how much real GDP increases when unemployment decreases by two percentage points.
"""

# ╔═╡ f261756b-856c-429f-93df-af0980e535b2
md"""
!!! answer "Answer (a)"

	Here
"""

# ╔═╡ a66fed79-59fe-4993-81c2-acbff747332a
md"""
!!! answer "Answer (b)"

	Here
"""

# ╔═╡ eef62e45-4ffc-4f1c-b1ba-92d55fb5ff2d
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 03706c92-80c5-41d7-bbc3-4e68d1873e77
md"""
## Exercise 8. The short-run AS curve
"""

# ╔═╡ 709997bf-ae42-49e8-8224-b9c2aae30bdb
md"""

*From the textbook.*

Assuming that the Okun’s law is given by $U - U_n = -0.5 (Y - Y^P)$ and that the Phillips curve is given by
$\pi=\pi^{e}-0.6(U-U_n)+\rho$

(a) Obtain the short-run aggregate supply curve if expectations are adaptive, inflation was 3% last year, and potential output is \$10 trillion (assume $\rho=0$).

(b) Calculate inflation when output is $8, $10, and $12 trillion dollars. 

(c) The figure below plots the short-run AS curve with three points. What happens to the unemployment rate when we move from points 1 to 2 and 3?

"""

# ╔═╡ df7eac78-5c6c-4307-b2ae-ad2331d99c4a
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ 66b70b7b-c792-44b7-8045-68ad836d1616
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ 7ee61691-f0ae-40c9-8d42-2ca45a3317d2
begin

	inflation(gdp) = 3.0 .+(0.6 .* 0.5).*(gdp .- 10.0) 		# this function represents the AS curve
	gdp = [8 , 10 , 12] 									# this vector contains the values of GDP
	inflation(gdp)											# this line prints the values of inflation
	
end

# ╔═╡ 926e7520-8c1e-4dc2-a9a5-0bafcd13bf47
begin
	output = 0:1:16
	
	PC = 3.0 .+(0.6 .* 0.5).*(output .- 10.0)
	
	trace7_24 = scatter(;x =output, y = PC, 
					name = "AS", line_color = "Blue", mode = "lines", 
					line_width="2.0")
		
	trace7_25 = scatter(; x = [8.0, 10.0, 12.0], y = [2.4, 3.0 , 3.6], text = ["1", "2" , "3"], 
					textposition = "top center", name = "", mode="markers+text", marker_size= "12",
					marker_color="blue",	
					textfont = attr(family="sans serif", size=16, color="black"))
	
	layout7_25 = Layout(;
					title_text = "The AS function",
					title_x = 0.5,
        			yaxis_title = "Rate of Inflation",
					yaxis_zeroline= false,
					hovermode="x",
        			xaxis_range = [4.0, 16],
        			xaxis_title = "GDP (trillion dollars)",
					xaxis_zeroline= false,
        			yaxis_range=[1, 5], 
        			titlefont_size=18)

	
	p7_25=Plot([trace7_24, trace7_25], layout7_25)
end

# ╔═╡ 506e4667-627c-4808-83be-ef9fe2211f87
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ e079d7e7-c04b-4014-a3bf-73c76004e683
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ eb7f7dff-8f31-4793-bcdd-1e1c47363abb
md"""
## Exercise 9. Oil prices and inflation
"""

# ╔═╡ 8022fa16-02c3-4481-b7ba-2fc1ded4f344
md"""
In this exercise, we will discuss the impact of international oil prices on inflation. The data is the same as in exercise 1.

a) In the following figure, we plot the evolution of oil prices since the 1960s. Mention three aspects that may be relevant for the analysis of inflation in a market economy.

"""

# ╔═╡ 0d2d4c66-b49c-46c0-8ed0-3906db9c8deb
begin
	trace7_51 = scatter(;x = Date.(period1_1), y = ASdata[:,5], name = "Oil", line_color = "Blue", 
						mode = "markers+lines", line_width="0.3", marker_size ="4")

	layout7_51 = Layout(;
		
				title_text = "OIl Prices in International Markets (1960--2022)",
				title_x = 0.5,
				xaxis_range = [Date(1959) , Date(2023)],
		
				hovermode="x",
		
            	xaxis = attr(
                title = "Monthly obervations",
                #tickformat = "%Y",
                #hoverformat = "%Y-M%m",
                #tick0 = "1970/01/01",
                #dtick = "M120",
        				),
        		#xaxis_range = [1960, 2020],
        		yaxis_title = "Dollars per Barrel",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)

	p7_51 = Plot([trace7_51], layout7_51)
end

# ╔═╡ 27746311-ce1b-4b68-9bc2-8dcf1306a593
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ 84238089-0c10-4c03-a494-073e4d317673
md"""

b) In the following figure, we show the annual growth rates of oil prices. Do you see anything peculiar in that figure than may have a crucial impact on inflation?

"""

# ╔═╡ 5ea54f91-bd86-4454-b6ef-3a97a0105ec2
begin
	trace7_61 = scatter(;x = Date.(period1_1), y = ASdata[:,4], name = "Oil", line_color = "Blue", 
						mode = "markers+lines", line_width="0.3", marker_size ="4")

	layout7_61 = Layout(;
		
				title_text = "Growth rate of oil Prices in International Markets (1960--2022)",
				title_x = 0.5,
				xaxis_range = [Date(1959) , Date(2023)],
		
				hovermode="x",
		
            	xaxis = attr(
                title = "Monthly obervations",
                #tickformat = "%Y",
                #hoverformat = "%Y-M%m",
                #tick0 = "1970/01/01",
                #dtick = "M120",
        				),
        		#xaxis_range = [1960, 2020],
        		yaxis_title = "Growth rate",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)

	p7_61 = Plot([trace7_61], layout7_61)
end

# ╔═╡ 4dbc64ac-79c2-4308-87c4-5e57e3c1e7a2
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ 241b7098-b3f3-4e36-81d4-dafa822c49c9
md"""

c) In the following figure, we show the relationship between inflation and the growth rate of oil prices for the period 2000-2022. What kind of relationship between those two variables do we have in that figure?

"""

# ╔═╡ ba40d0ff-992c-44de-b1a2-7ffe030bb3fd
period17_10 = MonthlyDate(2000, 1):Month(1):MonthlyDate(2022, 9);

# ╔═╡ 789b9f2b-4d0c-40b9-9ca4-809abbdfcba2
begin
	layout17_10 = Layout(;
					title_text = "Inflation versus Oil prices growth rate: USA 2010-2022",
					title_x = 0.5,
        			yaxis_title = "Rate of inflation",
        			xaxis_range = [-80, 150],
        			xaxis_title = "Oil prices growth rate",
        			#yaxis_range=[-80, 2], 
        			titlefont_size=18)

	p17_10 = Plot(ASdata[361+120:end,4], ASdata[361+120:end,2], mode="markers", text=period17_10,
            	marker_symbol="circle", marker_size="7",line_width=0.5, 
            	marker_color="brown", 
				layout17_10)
end

# ╔═╡ 3ede19ba-d5c1-4313-bd70-2d0ba03fa02c
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ b2bdb81a-1046-48da-b6e0-716ed2da7228
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 051bf8f6-d581-4a51-955f-02d78446c0f1
md"""
## Exercise 10. A comprehensive exercise
"""

# ╔═╡ df9417d2-ebe1-498c-b299-f2b8fdee1084
md"""

Consider the AS function as described in the slides and textbook:

$$\pi=\pi^{e}+\gamma\left(Y-Y^{P}\right)+\rho.$$

The following information is known:

$$\gamma=4.5 \quad , \quad Y^{P}=14.0 \quad , \quad  \pi^{e}=2.0 \quad , \quad \rho=0.0$$

a) In the following figure, we plot the short-run AS curve for the values of GDP between 12.5 and 15.5. We also plot the long-run AS curve. What do they represent?

b) What makes the economy move from points 1 to 2 and 2 to 3?

c) Suppose there is a shock in oil prices such that $\rho=3.0$. Using the slider **ρ8c** below, represent the impact of this shock upon the initial functions.

d) Is this oil price shock a positive or a negative type of shock?

"""

# ╔═╡ 9507f147-cf50-42f4-920e-9a472963f355
md"""
---
"""

# ╔═╡ 2a8fc4f2-ea8c-4ebf-ade6-1ffdd5e24ed8
md"""

Firstly, we should pass the parameters and exogenous variables to the notebook (index 8 is used to tell the notebook that these are the values of exercise 8).

"""

# ╔═╡ b28d588a-b4ff-444b-8b16-3cd05110ad1d
γ8 = 4.5 ; Yᴾ8 = 14.0 ; πᵉ8 = 2.0 ;	ρ8 = 0.0; 		#paremeters and exogenous variables 

# ╔═╡ 90c6188b-4356-415a-94ce-dc978d3b15ac
begin
	
	Y8 = 12.0:0.01:16.0
	
	π8 = πᵉ8 .+ γ8 .*(Y8 .- Yᴾ8) .+ρ8
	
	trace7_40 = scatter(; x = Y8, y = π8, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	
	trace7_41 = scatter(; x = [13.5, 14.0, 14.5], y = [-0.25, 2.0, 4.25], text = ["1", "2" , "3"], 
					textposition = "top center", name = "", mode="markers+text", marker_size= "12",
					marker_color="Red",	
					textfont = attr(family="sans serif", size=16, color="black"))
	
	trace7_49 = scatter(; x = [14,14] , y = [-7,14] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	
	layout7_41 = Layout(;
					title_text = "The AS function", titlefont_size=18,
					title_x = 0.5,
                     xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
					 hovermode="x",
                     xaxis_range = [12.5, 15.5],
                     yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					 yaxis_range = [-5.0, 10.0])
	
	p7_41 = Plot([trace7_49, trace7_40, trace7_41], layout7_41)
	
end

# ╔═╡ 03c7091d-7830-4fad-b444-413454736d5b
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ 239ccedb-f91d-4eb1-9a69-588bf4ff4ebc
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ db2990be-db70-456f-96c4-9de707bfcfbd
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ 8430162f-4f13-4525-9260-027d84222808
md"""
`ρ8c = `$(@bind ρ8c Slider(-6.0:0.25:6.0, default=0.0, show_value=true))
"""

# ╔═╡ ae1c8887-678f-4485-a492-a1b06e7aaefa
begin
	
	#Y8 = 12.0:0.01:16.0
	
	π8Δρ = πᵉ8 .+ γ8 .*(Y8 .- Yᴾ8) .+ ρ8c
	
	trace7_43 = scatter(; x = Y8, y = π8Δρ, mode="lines" , line_color = "Gray", line_width = "3",
			name  = "AS2")
	
	trace7_44 = scatter(; x = [13.5, 14.0, 14.5], y = [2.75, 5.0, 7.25], text =["1'", "2'" , "3'"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Gray", 
					textfont = attr(family="sans serif", size=16, color="black"))
	
	trace7_45 = scatter(; x = [12.83333, 13.33333, 13.833333], y = [-0.25, 2.0, 4.25], 
					text =["1''", "2''" , "3''"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Orange", 
					textfont = attr(family="sans serif", size=16, color="black"))
	
	layout7_44 = Layout(;
					title_text = "The AS function with a negative supply shock", titlefont_size=18,
					title_x = 0.5,
                     xaxis=attr(title=" GDP (trillion dollars)", showgrid=true, zeroline=false),
                     xaxis_range = [12.5, 15.5],
					 hovermode="x",
                     yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					 yaxis_range = [-5.0, 13.0])
	
	p7_44 = Plot([trace7_49, trace7_43, trace7_40, trace7_44, trace7_41], layout7_44)
	
end

# ╔═╡ 7d77dff4-dbe2-4ee0-9be3-fbdaee9edaa8
md"""
!!! answer "Answer (d)"

	Here


"""

# ╔═╡ f3b6fae7-44de-496d-98a3-11f416e62f20
md"""
`ρ8d = `$(@bind ρ8d Slider(-6.0:0.25:6.0, default=0.0, show_value=true))
"""

# ╔═╡ 34161592-b86c-428e-ad0f-6c7b6c8c1be5
begin
	
	#Y8 = 12.0:0.01:16.0
	
	π8Δρ_d = πᵉ8 .+ γ8 .*(Y8 .- Yᴾ8) .+ ρ8d
	
	trace7_53 = scatter(; x = Y8, y = π8Δρ_d, mode="lines" , line_color = "Gray", line_width = "3",
			name  = "AS2")
	
	
	trace7_55 = scatter(; x = [12.83333, 13.33333, 13.833333], y = [-0.25, 2.0, 4.25], 
					text =["1''", "2''" , "3''"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Orange", 
					textfont = attr(family="sans serif", size=16, color="black"))
	
	layout7_54 = Layout(;
					title_text = "The AS function with a negative supply shock", titlefont_size=18,
					title_x = 0.5,
                     xaxis=attr(title=" GDP (trillion dollars)", showgrid=true, zeroline=false),
                     xaxis_range = [12.5, 15.5],
					 hovermode="x",
                     yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					 yaxis_range = [-5.0, 13.0])
	
	p7_54 = Plot([trace7_49, trace7_53, trace7_40, trace7_55, trace7_41], layout7_54)
	
end

# ╔═╡ aafdc1f7-7f2a-454c-b3da-9c9c68aed107
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 9cd31e46-2efd-4cb7-a1fb-833fb0214d84
md"""
# Auxiliary cells (do not delete)
"""

# ╔═╡ a385a0ae-d2e0-4b4e-862c-e69ec5bd6843
html"""<style>
main {
    max-width: 900px;
    align-self: flex-start;
    margin-left: 100px;
}
"""


# ╔═╡ 9fa87191-7c90-4738-a45a-acd929c8bd1b
  TableOfContents()

# ╔═╡ 8205aa02-e1a1-433a-a4ff-7491dd07faa7


# ╔═╡ 564c8af7-7df7-47d5-909c-d0718e43584e
md"""
#### Exercise 6. Supporting cells
"""

# ╔═╡ 1e269aef-f564-4f6b-aaf5-f3a34e03001a
USdata = CSV.read("US_Data_May2021.csv", DataFrame);

# ╔═╡ 7b1b099a-68e7-4038-a4dd-d1e7321c79f0
md"""
The function `hp_filter` will be used to obtain the long term trend in the data (but you do not need to worry about it at all)
"""

# ╔═╡ 1f6f07ea-751b-4a47-85f8-9709f0af06d9
begin
	function hp_filter(USdata::Array{Float64,1}, lambda::Float64)
    	n = length(USdata)
    	@assert n >= 4
    	diag2 = lambda*ones(n-2)
    	diag1 = [ -2lambda; -4lambda*ones(n-3); -2lambda ]
    	diag0 = [ 1+lambda; 1+5lambda; (1+6lambda)*ones(n-4); 1+5lambda; 1+lambda ]
    	D = spdiagm(-2 => diag2, -1 => diag1, 0 => diag0, 1 => diag1, 2 => diag2)
    	D\USdata
	end
end

# ╔═╡ d6557f28-2d14-4d42-9c6f-ad1d114595de
period7_8 = QuarterlyDate(1960, 1):Quarter(1):QuarterlyDate(2019, 4);

# ╔═╡ b5e27f26-96cc-4409-a56c-489336d906a2
begin
	GDP = log.(USdata[1:240, 2]); # We consider only the pre-COVID period (last 4 obervations dropped)
	U = (USdata[1:240, 8]); # We consider only the pre-COVID period (last 4 obervations dropped)

	# GDP
	GDP_hptrend = hp_filter(GDP, 1600.0);
	GDP_cycles = (GDP-GDP_hptrend)*100;

	# Unemployment
	U_hptrend = hp_filter(U, 1600.0);
	U_cycles = U-U_hptrend;
end;


# ╔═╡ 3da18742-5278-4fdf-8f04-30c4b4706fb2
begin
	trace7_12 = scatter(;x = Date.(period7_8), y = U, name = "U", line_color = "Blue", 
						mode = "markers+lines", line_width="0.3", marker_size ="5")
	
	trace7_13 = scatter(;x = Date.(period7_8), y = U_hptrend, name = "Trend", line_color = "Red", 
						mode = "markers+lines", line_width="0.3", marker_size ="5")

	layout7_13 = Layout(;
		
				title_text = "Fig 6.1. US Unemployment and its Trend (1960.Q1--2019.Q4)",
				title_x = 0.5,
				xaxis_range = [Date(1959) , Date(2021)],
		
				hovermode="x",
		
            	xaxis = attr(
                title = "Quarterly obervations",
                tickformat = "%Y",
                hoverformat = "%Y-Q%q",
                tick0 = "1960/04/01",
                dtick = "M120",
        				),
        		#xaxis_range = [1960, 2020],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)

	p7_13 = Plot([trace7_12, trace7_13], layout7_13)
end

# ╔═╡ 0afd818b-856a-4000-82ac-a7e68cb48391
begin
	trace7_14 = scatter(;x = Date.(period7_8), y = U_cycles, name = "U cyclical", line_color = "darkred", 
						mode = "markers+lines", line_width="0.3", marker_size ="5")

	layout7_14 = Layout(;
		
				title_text = "Fig 6.2. US Cyclical Unemployment (1960.Q1--2019.Q4)",
				title_x = 0.5,
				xaxis_range = [Date(1959) , Date(2021)],
		
				hovermode="x",
		
            	xaxis = attr(
                title = "Quarterly obervations",
                tickformat = "%Y",
                hoverformat = "%Y-Q%q",
                tick0 = "1960/04/01",
                dtick = "M120",
        				),
        		#xaxis_range = [1960, 2020],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)

	p7_14 = Plot([trace7_14], layout7_14)
end

# ╔═╡ 9e354338-1870-4d17-b470-2e1beda77aa1
begin
	trace7_15 = scatter(;x = Date.(period7_8), y = GDP, name = "GDP", line_color = "Blue", 
						mode = "lines", line_width="1.5")
	
	trace7_16 = scatter(;x = Date.(period7_8), y = GDP_hptrend, name = "Trend", line_color = "Red", 
						mode = "lines", line_width="1.5")

	layout7_16 = Layout(;
		
				title_text = "Fig 6.3. GDP and its Trend (1960.Q1--2019.Q4)",
				title_x = 0.5,
		
				hovermode="x",
		
            	xaxis = attr(
                title = "Quarterly obervations",
                tickformat = "%Y",
                hoverformat = "%Y-Q%q",
                tick0 = "1960/04/01",
                dtick = "M120",
        				),
        		#xaxis_range = [1960, 2020],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)

	p7_16 = Plot([trace7_15, trace7_16], layout7_16)
end

# ╔═╡ e105541d-b332-4488-a3fe-870b9c3ca232
begin
	trace7_17 = scatter(;x = Date.(period7_8), y = GDP_cycles, name = "Output-gap", line_color = "DarkRed", 
						mode = "markers+lines", line_width="0.3", marker_size ="5")

	layout7_17 = Layout(;
		
				title_text = "Fig 6.4. Output Gap (1960.Q1--2019.Q4)",
				title_x = 0.5,
				xaxis_range = [Date(1959) , Date(2021)],
		
				hovermode="x",
		
            	xaxis = attr(
                title = "Quarterly obervations",
                tickformat = "%Y",
                hoverformat = "%Y-Q%q",
                tick0 = "1960/04/01",
                dtick = "M120",
        				),
        		#xaxis_range = [1960, 2020],
        		yaxis_title = "Percentage points",
        		#yaxis_range=[-2, 2], 
        		titlefont_size = 16)

	p7_17 = Plot([trace7_17], layout7_17)
end

# ╔═╡ 781d785f-987b-4eb4-aeac-1a3277d6d0ea
begin
	# linear regression using Julia's linear algebra
	X = hcat(ones(length(GDP_cycles)),GDP_cycles)
	Y = U_cycles
	intercept,slope = inv(X'* X)*(X'* Y)
end;

# ╔═╡ 8fef9bcd-2cc7-4ff3-87ed-9d0fba75dd1b
begin
	gap = -5:0.01:4
	Okun = slope .* gap
	Print(slope)
end;

# ╔═╡ 1eabd160-ae3c-4c97-9c0e-ae0b95fdf8bb
begin
	
	trace7_20 = scatter(; x = GDP_cycles , y = U_cycles, mode="markers+lines" , text=period7_8,
					marker_symbol="circle", marker_size="7", line_width=0.4, 
					marker_color="Blue", name  = "Points")

	trace7_31 = scatter(; x=gap, y = Okun,
			line_width= 3, 
            line_dash="solid", 
            line_color="Red",
            #line_color="Pink",
            name="Okun's Law")
	
	
	layout7_20 = Layout(;
					title_text = "Fig 6.5. The Okun's Law: USA (1960.Q1--2019.Q4)",
					title_x = 0.5,
        			yaxis_title = "Cyclical unemployment",
		  			#xaxis_range = [1960, 2020],
        			xaxis_title = "Output-gap",
        			#yaxis_range=[-2, 2], 
        			titlefont_size=18)

	p7_20 = Plot([trace7_20 , trace7_31 ], layout7_20)
	#addtraces(p7_10, t22)
	
end

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
CSV = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
PeriodicalDates = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
PlotlyBase = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
StatsBase = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"

[compat]
CSV = "~0.10.9"
DataFrames = "~1.5.0"
HypertextLiteral = "~0.9.4"
PeriodicalDates = "~2.0.0"
PlotlyBase = "~0.8.19"
PlutoUI = "~0.7.50"
StatsBase = "~0.33.21"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.8.5"
manifest_format = "2.0"
project_hash = "ee37cd7188d677b377d62c8106c60136196fb3c5"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "8eaf9f1b4921132a4cff3f36a1d9ba923b14a481"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.1.4"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.1"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"

[[deps.CSV]]
deps = ["CodecZlib", "Dates", "FilePathsBase", "InlineStrings", "Mmap", "Parsers", "PooledArrays", "SentinelArrays", "SnoopPrecompile", "Tables", "Unicode", "WeakRefStrings", "WorkerUtilities"]
git-tree-sha1 = "c700cce799b51c9045473de751e9319bdd1c6e94"
uuid = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
version = "0.10.9"

[[deps.ChainRulesCore]]
deps = ["Compat", "LinearAlgebra", "SparseArrays"]
git-tree-sha1 = "c6d890a52d2c4d55d326439580c3b8d0875a77d9"
uuid = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
version = "1.15.7"

[[deps.ChangesOfVariables]]
deps = ["ChainRulesCore", "LinearAlgebra", "Test"]
git-tree-sha1 = "485193efd2176b88e6622a39a246f8c5b600e74e"
uuid = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
version = "0.1.6"

[[deps.CodecZlib]]
deps = ["TranscodingStreams", "Zlib_jll"]
git-tree-sha1 = "9c209fb7536406834aa938fb149964b985de6c83"
uuid = "944b1d66-785c-5afd-91f1-9de20f533193"
version = "0.7.1"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "Random", "SnoopPrecompile"]
git-tree-sha1 = "aa3edc8f8dea6cbfa176ee12f7c2fc82f0608ed3"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.20.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "eb7f0f8307f71fac7c606984ea5fb2817275d6e4"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.4"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "SpecialFunctions", "Statistics", "TensorCore"]
git-tree-sha1 = "600cc5508d66b78aae350f7accdb58763ac18589"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.9.10"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "fc08e5930ee9a4e03f84bfb5211cb54e7769758a"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.10"

[[deps.Compat]]
deps = ["Dates", "LinearAlgebra", "UUIDs"]
git-tree-sha1 = "7a60c856b9fa189eb34f5f8a6f6b5529b7942957"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.6.1"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.0.1+0"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DataAPI]]
git-tree-sha1 = "e8119c1a33d267e16108be441a287a6981ba1630"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.14.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "Future", "InlineStrings", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrettyTables", "Printf", "REPL", "Random", "Reexport", "SentinelArrays", "SnoopPrecompile", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "aa51303df86f8626a962fccb878430cdb0a97eee"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.5.0"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "d1fff3a548102f48987a52a2e0d114fa97d730f0"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.13"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FilePathsBase]]
deps = ["Compat", "Dates", "Mmap", "Printf", "Test", "UUIDs"]
git-tree-sha1 = "e27c4ebe80e8699540f2d6c805cc12203b614f12"
uuid = "48062228-2e41-5def-b9a4-89aafe57970f"
version = "0.9.20"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "335bfdceacc84c5cdf16aadc768aa5ddfc5383cc"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.4"

[[deps.Formatting]]
deps = ["Printf"]
git-tree-sha1 = "8339d61043228fdd3eb658d86c926cb282ae72a8"
uuid = "59287772-0a20-5a39-b81b-1366585eb4c0"
version = "0.4.2"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "8d511d5b81240fc8e6802386302675bdf47737b9"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.4"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "c47c5fa4c5308f27ccaac35504858d8914e102f9"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.4"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "f7be53659ab06ddc986428d3a9dcc95f6fa6705a"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.2"

[[deps.InlineStrings]]
deps = ["Parsers"]
git-tree-sha1 = "9cc2baf75c6d09f9da536ddf58eb2f29dedaf461"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"

[[deps.InverseFunctions]]
deps = ["Test"]
git-tree-sha1 = "49510dfcb407e572524ba94aeae2fced1f3feb0f"
uuid = "3587e190-3f89-42d0-90ee-14403ec27112"
version = "0.1.8"

[[deps.InvertedIndices]]
git-tree-sha1 = "0dc7b50b8d436461be01300fd8cd45aa0274b038"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.0"

[[deps.IrrationalConstants]]
git-tree-sha1 = "630b497eafcc20001bba38a4651b327dcfc491d2"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.2"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JLLWrappers]]
deps = ["Preferences"]
git-tree-sha1 = "abc9885a7ca2052a736a600f7fa66209f96506e1"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.4.1"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "3c837543ddb02250ef42f4738347454f95079d4e"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.3"

[[deps.LaTeXStrings]]
git-tree-sha1 = "f2355693d6778a178ade15952b7ac47a4ff97996"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.3.0"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.3"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "7.84.0+0"

[[deps.LibGit2]]
deps = ["Base64", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.10.2+0"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"

[[deps.LinearAlgebra]]
deps = ["Libdl", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"

[[deps.LogExpFunctions]]
deps = ["ChainRulesCore", "ChangesOfVariables", "DocStringExtensions", "InverseFunctions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "0a1b7c2863e44523180fdb3146534e265a91870b"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.23"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"

[[deps.MIMEs]]
git-tree-sha1 = "65f28ad4b594aebe22157d6fac869786a255b7eb"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "0.1.4"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.0+0"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "f66bdc5de519e8f8ae43bdc598782d35a25b1272"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.1.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2022.2.1"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.20+0"

[[deps.OpenLibm_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "05823500-19ac-5b8b-9628-191a04bc5112"
version = "0.8.1+0"

[[deps.OpenSpecFun_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "JLLWrappers", "Libdl", "Pkg"]
git-tree-sha1 = "13652491f6856acfd2db29360e1bbcd4565d04f1"
uuid = "efe28fd5-8261-553b-a9e1-b2916fc3738e"
version = "0.5.5+0"

[[deps.OrderedCollections]]
git-tree-sha1 = "85f8e6578bf1f9ee0d11e7bb1b1456435479d47c"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.4.1"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "SnoopPrecompile"]
git-tree-sha1 = "478ac6c952fddd4399e71d4779797c538d0ff2bf"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.5.8"

[[deps.PeriodicalDates]]
deps = ["Dates", "Printf", "RecipesBase"]
git-tree-sha1 = "e616941f8093e50a373e7d51875143213f82eca4"
uuid = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
version = "2.0.0"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "Serialization", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.8.0"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "5bb5129fdd62a2bbbe17c2756932259acf467386"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.50"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "a6062fe4063cdafe78f4a0a81cfffb89721b30e7"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.2"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "47e5f437cc0e7ef2ce8406ce1e7e24d44915f88d"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.3.0"

[[deps.PrettyTables]]
deps = ["Crayons", "Formatting", "LaTeXStrings", "Markdown", "Reexport", "StringManipulation", "Tables"]
git-tree-sha1 = "548793c7859e28ef026dba514752275ee871169f"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "2.2.3"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"

[[deps.Random]]
deps = ["SHA", "Serialization"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"

[[deps.RecipesBase]]
deps = ["SnoopPrecompile"]
git-tree-sha1 = "261dddd3b862bd2c940cf6ca4d1c8fe593e457c8"
uuid = "3cdcf5f2-1ef4-517c-9805-6587b60abb01"
version = "1.3.3"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "77d3c4726515dca71f6d80fbb5e251088defe305"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.3.18"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"

[[deps.SnoopPrecompile]]
deps = ["Preferences"]
git-tree-sha1 = "e760a70afdcd461cf01a575947738d359234665c"
uuid = "66db9d55-30c0-4569-8b51-7e840670fc0c"
version = "1.0.3"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "a4ada03f999bd01b3a25dcaa30b2d929fe537e00"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.1.0"

[[deps.SparseArrays]]
deps = ["LinearAlgebra", "Random"]
uuid = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.SpecialFunctions]]
deps = ["ChainRulesCore", "IrrationalConstants", "LogExpFunctions", "OpenLibm_jll", "OpenSpecFun_jll"]
git-tree-sha1 = "ef28127915f4229c971eb43f3fc075dd3fe91880"
uuid = "276daf66-3868-5448-9aa4-cd146d93841b"
version = "2.2.0"

[[deps.Statistics]]
deps = ["LinearAlgebra", "SparseArrays"]
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "f9af7f195fb13589dd2e2d57fdb401717d2eb1f6"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.5.0"

[[deps.StatsBase]]
deps = ["DataAPI", "DataStructures", "LinearAlgebra", "LogExpFunctions", "Missings", "Printf", "Random", "SortingAlgorithms", "SparseArrays", "Statistics", "StatsAPI"]
git-tree-sha1 = "d1bf48bfcc554a3761a133fe3a9bb01488e06916"
uuid = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"
version = "0.33.21"

[[deps.StringManipulation]]
git-tree-sha1 = "46da2434b41f41ac3594ee9816ce5541c6096123"
uuid = "892a3eda-7b42-436c-8928-eab12a02cf0e"
version = "0.3.0"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.0"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "LinearAlgebra", "OrderedCollections", "TableTraits", "Test"]
git-tree-sha1 = "1544b926975372da01227b382066ab70e574a3ec"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.10.1"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.1"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"

[[deps.TranscodingStreams]]
deps = ["Random", "Test"]
git-tree-sha1 = "94f38103c984f89cf77c402f2a68dbd870f8165f"
uuid = "3bb67fe8-82b1-5028-8e26-92a6c54297fa"
version = "0.9.11"

[[deps.Tricks]]
git-tree-sha1 = "6bac775f2d42a611cdfcd1fb217ee719630c4175"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.6"

[[deps.URIs]]
git-tree-sha1 = "074f993b0ca030848b897beff716d93aca60f06a"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.4.2"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.WorkerUtilities]]
git-tree-sha1 = "cd1659ba0d57b71a464a29e64dbc67cfe83d54e7"
uuid = "76eceee3-57b5-4d4a-8e66-0e911cebbf60"
version = "1.6.1"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.12+3"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl", "OpenBLAS_jll"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.1.1+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.48.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+0"
"""

# ╔═╡ Cell order:
# ╟─943edb36-acc8-4b2a-94ab-c544f9eb279b
# ╟─1245aef9-18ce-42f5-af82-c2e6cce70798
# ╟─4618a663-f77e-4ccc-9b00-e84dbd5beb34
# ╠═a145e2fe-a903-11eb-160f-df7ea83fa3e6
# ╟─74de9f66-d5b4-4e0f-a75d-5177b1842191
# ╟─add07024-b7eb-445d-b4f4-6a6757c2ecd3
# ╟─bfb890be-fba4-4d55-9e39-a52d40a5adad
# ╟─ec4b312d-c945-4d24-ad88-6fa15ed6f0f1
# ╠═518caed6-cb92-4410-bc0a-7a5c7bdc155e
# ╟─f613e456-403b-4bff-bd65-315b1be5eb45
# ╟─6c66bff7-47ef-4926-8d56-2c92d6eb485b
# ╟─fdec5907-d925-4ae2-9298-fd14f3213139
# ╟─78475df7-5d81-410c-97bb-9ce06e897a7e
# ╟─b31105dd-a43d-4640-a13c-e19f7e879ca2
# ╟─7bc32249-45ff-42bf-8d39-ec1a7670fbdd
# ╟─04b850b4-e659-4f1c-82be-ba912bad03af
# ╟─066f8df6-7d9c-4137-b0a2-5f1c5eb3a1d7
# ╟─24f2f06e-05fe-4b12-b238-d660f449ee9b
# ╟─4215ce6d-b49f-4dcb-a9de-5be9661d65f2
# ╟─793b3108-76c1-4274-9861-c9ee948eca88
# ╟─24f78b7c-7bda-4ea1-b593-bdacb94e8c4d
# ╟─86194b6d-e8e0-4790-ab47-d12f691beef2
# ╟─aa86d58a-214d-4ef3-a2a3-86b78af55967
# ╟─a6a4a528-b4eb-4521-9cba-d8a02b0c3720
# ╟─af88f312-87dd-4a1e-913d-31ba12f06b45
# ╟─f4d5a7be-361c-4a52-b501-b363548e42ee
# ╟─dcd13560-0f73-4aaa-b59a-b7961d8cdc63
# ╟─7f67d656-bb55-4097-ba49-10140f9b3502
# ╟─beb52783-708e-4782-b271-643f2a4f3297
# ╟─66463532-449b-4cac-8083-8938786a193b
# ╟─28e51405-60fb-496c-b3cd-5aa256243b8e
# ╟─57787a16-2568-4fcb-94cf-7f5533facf05
# ╟─a91c2b80-3215-46ac-938c-ef98e4dde437
# ╟─95dce14a-b5f9-4dd8-af46-415e71b425fb
# ╟─62d8a5a1-eab1-49ae-8947-b5299d1217c5
# ╟─6949d31b-c934-42f8-a53e-8fd1e068fff4
# ╟─95b7bd36-e0fc-4464-8bbe-9e9f491dae64
# ╟─21d79f5f-f03a-4d63-8f79-d8868bd9234d
# ╟─763bc186-dae2-479c-8195-6585b46733be
# ╟─6c8886d7-3dec-4d2f-8aa9-85ad714cee7f
# ╟─f0196aef-6843-4f69-b387-ca5deec33604
# ╟─10ccbe74-dff0-4f84-9b8d-3563559be3ba
# ╟─d333ae08-ecb5-454f-a963-2dc33583d21c
# ╟─adc62dc5-e66e-4eba-9eb5-4cea6dd0efa9
# ╟─b210c2e6-c9a5-44d8-a01c-c9702da0606d
# ╟─aea3a28e-c408-4a6d-ac6a-1507ed4e4d1b
# ╟─c1a3d11b-881c-4c74-ac1d-e794562349e0
# ╟─778b7504-2f80-480e-bf43-cdbea4be4514
# ╟─854c4538-8d47-41f6-ba61-edfd81f632d1
# ╟─2d9beabe-d549-4bc3-9598-adb01169ffa0
# ╟─3cf86819-09f0-43d3-aff7-494be276bf0f
# ╟─ccc8aa66-cb8d-4bbe-8457-f496f7bff47d
# ╟─3da18742-5278-4fdf-8f04-30c4b4706fb2
# ╟─0afd818b-856a-4000-82ac-a7e68cb48391
# ╟─dc5bfa8c-7247-44fc-8837-a7fa32c36d54
# ╟─d040f3bb-7ea9-4000-813a-6e1f4e0163cb
# ╟─9e354338-1870-4d17-b470-2e1beda77aa1
# ╟─e105541d-b332-4488-a3fe-870b9c3ca232
# ╟─ea2e3d0e-c933-4d67-ac24-3ba9bcf6fc8a
# ╟─2ab10860-0671-4e3c-a7ea-dff6ae80c528
# ╟─1eabd160-ae3c-4c97-9c0e-ae0b95fdf8bb
# ╟─cc770177-1d7a-4f6e-a930-c805b3bfee6d
# ╟─707413b6-3726-430c-a3b4-8cc768b448dc
# ╟─86f54c54-58a5-4faf-9688-baddaa032ed2
# ╟─c0bb7086-533d-4c95-850a-b445b877d8c8
# ╟─f261756b-856c-429f-93df-af0980e535b2
# ╟─a66fed79-59fe-4993-81c2-acbff747332a
# ╟─eef62e45-4ffc-4f1c-b1ba-92d55fb5ff2d
# ╟─03706c92-80c5-41d7-bbc3-4e68d1873e77
# ╟─709997bf-ae42-49e8-8224-b9c2aae30bdb
# ╟─df7eac78-5c6c-4307-b2ae-ad2331d99c4a
# ╟─66b70b7b-c792-44b7-8045-68ad836d1616
# ╠═7ee61691-f0ae-40c9-8d42-2ca45a3317d2
# ╟─926e7520-8c1e-4dc2-a9a5-0bafcd13bf47
# ╟─506e4667-627c-4808-83be-ef9fe2211f87
# ╟─e079d7e7-c04b-4014-a3bf-73c76004e683
# ╟─eb7f7dff-8f31-4793-bcdd-1e1c47363abb
# ╟─8022fa16-02c3-4481-b7ba-2fc1ded4f344
# ╟─0d2d4c66-b49c-46c0-8ed0-3906db9c8deb
# ╟─27746311-ce1b-4b68-9bc2-8dcf1306a593
# ╟─84238089-0c10-4c03-a494-073e4d317673
# ╟─5ea54f91-bd86-4454-b6ef-3a97a0105ec2
# ╟─4dbc64ac-79c2-4308-87c4-5e57e3c1e7a2
# ╟─241b7098-b3f3-4e36-81d4-dafa822c49c9
# ╟─ba40d0ff-992c-44de-b1a2-7ffe030bb3fd
# ╟─789b9f2b-4d0c-40b9-9ca4-809abbdfcba2
# ╟─3ede19ba-d5c1-4313-bd70-2d0ba03fa02c
# ╟─b2bdb81a-1046-48da-b6e0-716ed2da7228
# ╟─051bf8f6-d581-4a51-955f-02d78446c0f1
# ╟─df9417d2-ebe1-498c-b299-f2b8fdee1084
# ╟─9507f147-cf50-42f4-920e-9a472963f355
# ╟─2a8fc4f2-ea8c-4ebf-ade6-1ffdd5e24ed8
# ╠═b28d588a-b4ff-444b-8b16-3cd05110ad1d
# ╟─90c6188b-4356-415a-94ce-dc978d3b15ac
# ╟─03c7091d-7830-4fad-b444-413454736d5b
# ╟─239ccedb-f91d-4eb1-9a69-588bf4ff4ebc
# ╟─db2990be-db70-456f-96c4-9de707bfcfbd
# ╟─8430162f-4f13-4525-9260-027d84222808
# ╟─ae1c8887-678f-4485-a492-a1b06e7aaefa
# ╟─7d77dff4-dbe2-4ee0-9be3-fbdaee9edaa8
# ╟─f3b6fae7-44de-496d-98a3-11f416e62f20
# ╟─34161592-b86c-428e-ad0f-6c7b6c8c1be5
# ╟─aafdc1f7-7f2a-454c-b3da-9c9c68aed107
# ╟─9cd31e46-2efd-4cb7-a1fb-833fb0214d84
# ╠═a385a0ae-d2e0-4b4e-862c-e69ec5bd6843
# ╠═9fa87191-7c90-4738-a45a-acd929c8bd1b
# ╟─8205aa02-e1a1-433a-a4ff-7491dd07faa7
# ╟─564c8af7-7df7-47d5-909c-d0718e43584e
# ╟─1e269aef-f564-4f6b-aaf5-f3a34e03001a
# ╟─7b1b099a-68e7-4038-a4dd-d1e7321c79f0
# ╟─1f6f07ea-751b-4a47-85f8-9709f0af06d9
# ╟─d6557f28-2d14-4d42-9c6f-ad1d114595de
# ╟─781d785f-987b-4eb4-aeac-1a3277d6d0ea
# ╟─b5e27f26-96cc-4409-a56c-489336d906a2
# ╟─8fef9bcd-2cc7-4ff3-87ed-9d0fba75dd1b
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
